@@ -1,4 +1,4 @@
-// Copyright (c) 2001-2002 Rob Kaper <cap@capsi.com>,
+// Copyright (c) 2001-2004 Rob Kaper <cap@capsi.com>,
 //               2001 Erik Bourget <ebourg@cs.mcgill.ca>
 //
 // This program is free software; you can redistribute it and/or
@@ -22,8 +22,19 @@ class MonopdServer;
 class Socket;
 
 #include <string>
+#include <libcapsinetwork/listener.h>
+
+class MonopdListener : public Listener
+{
+public:
+	MonopdListener( MonopdServer *server );
+	void socketHandler( Socket *socket, const std::string &data = "" );
+
+private:
+	Listener *m_listener;
+	MonopdServer *m_server;
+};
 
 int main(int, char **);
-void socket_handler(Socket *, std::string data);
 
 #endif
