@@ -1,4 +1,4 @@
-// Copyright (c) 2001-2003 Rob Kaper <cap@capsi.com>,
+// Copyright (c) 2001-2004 Rob Kaper <cap@capsi.com>,
 //               2001 Erik Bourget <ebourg@cs.mcgill.ca>
 //
 // This program is free software; you can redistribute it and/or
@@ -42,12 +42,17 @@ Player::Player(Socket *socket, int id) : GameObject(id, GameObject::GPlayer)
 
 Player::~Player()
 {
-	delete m_display;
+    while (!m_cards.empty()) { delete *m_cards.begin(); m_cards.erase(m_cards.begin()); }
+
+    delete m_display;
 }
 
 void Player::reset(bool removeProperties)
 {
+    while (!m_cards.empty()) { delete *m_cards.begin(); m_cards.erase(m_cards.begin()); }
+
 	m_estate = m_destination = m_tokenLocation = 0;
+
 	if (removeProperties)
 	{
 		removeProperty("money");
@@ -67,6 +72,7 @@ void Player::reset(bool removeProperties)
 	}
 	m_requestedUpdate = false;
 
+	m_display->setEstate(0);
 	m_display->resetButtons();
 }
 
@@ -153,6 +159,12 @@ void Player::ioNoSuchCmd(const std::string data)
 		ioError("No such command.");
 }
 
+void Player::setDisplay(Estate *estate)
+{
+	m_display->setEstate(estate);
+	m_display->resetButtons();
+}
+
 void Player::setDisplay(Estate *estate, const char *data, ...)
 {
 	va_list arg;
@@ -163,16 +175,15 @@ void Player::setDisplay(Estate *estate, const char *data, ...)
 	va_end(arg);
 	buf[sizeof(buf)-1] = 0;
 
-	m_display->setEstate(estate);
+	setDisplay(estate);
 	m_display->setText(std::string(buf));
 	m_display->resetButtons();
 }
 
 void Player::setDisplay(Estate *estate, const std::string data)
 {
-	m_display->setEstate(estate);
+	setDisplay(estate);
 	m_display->setText(data);
-	m_display->resetButtons();
 }
 
 void Player::setDisplayClearText(bool clearText)
@@ -477,7 +488,7 @@ void Player::sellEstate(int estateId)
 	m_game->setDisplay(estate, false, false, "%s sold %s for %d.", getStringProperty("name").c_str(), estate->getStringProperty("name").c_str(), sellPrice);
 
 	if (getBoolProperty("hasdebt"))
-		m_game->solveDebt(this);
+		m_game->solveDebts(this);
 }
 
 void Player::mortgageEstate(int estateId)
@@ -523,7 +534,7 @@ void Player::mortgageEstate(int estateId)
 		m_game->setDisplay(estate, false, false, "%s mortgaged %s for %d.", getStringProperty("name").c_str(), estate->getStringProperty("name").c_str(), estate->getIntProperty("mortgageprice"));
 
 		if (getBoolProperty("hasdebt"))
-			m_game->solveDebt(this);
+			m_game->solveDebts(this);
 	}
 }
 
@@ -695,7 +706,7 @@ void Player::sellHouse(int estateId)
 	}
 
 	m_game->sendMsgEstateUpdate(estate);
-	m_game->solveDebt(this);
+	m_game->solveDebts(this);
 }
 
 void Player::updateTradeObject(char *data)
