@@ -45,7 +45,7 @@ MonopdServer::MonopdServer() : GameObject(0)
 	m_nextGameId = m_nextPlayerId = 1;
 	m_gatorIdentity = "";
 	m_port = 1234;
-	m_gatorHost = "gator.monopd.net";
+	m_gatorHost = "monopd.unixcode.org";
 	m_gatorPort = 80;
 	m_gatorFrequency = 60;
 	m_useMonopigator = false;
@@ -82,12 +82,11 @@ void MonopdServer::delEvent(Event *event)
 	for(std::vector<Event *>::iterator it = m_events.begin(); it != m_events.end() && (*it) ; ++it)
 		if (*it == event)
 		{
-			printf("delEvent %d/%d\n", event->id(), m_events.size());
+			printf("delEvent %d/%d\n", event->id(), m_events.size()-1);
 			delete event;
 			m_events.erase(it);
 			break;
 		}
-	printf("delEvent -/%d\n", m_events.size());
 }
 
 Event *MonopdServer::findEvent(Game *game, unsigned int eventType)
@@ -100,11 +99,19 @@ Event *MonopdServer::findEvent(Game *game, unsigned int eventType)
 	return 0;
 }
 
+Event *MonopdServer::findEvent(Game *game, GameObject *object)
+{
+	for(std::vector<Event *>::iterator it = m_events.begin(); it != m_events.end() && (*it) ; ++it)
+		if ( (*it)->game() == game && (*it)->object() == object)
+			return (*it);
+
+	return 0;
+}
+
 void MonopdServer::newGame(Player *player, const std::string gameType)
 {
 	Game *game = new Game(m_nextGameId++);
 	m_games.push_back(game);
-	printf("newGame %d/%d\n", game->id(), m_games.size());
 
 	game->setProperty("name", (gameType.size() ? gameType : "atlantic"), this);
 
@@ -122,9 +129,12 @@ void MonopdServer::newGame(Player *player, const std::string gameType)
 	{
 		delGame(game, false);
 		player->ioWrite("<monopd><msg type=\"error\" value=\"Could not load valid configuration for gametype %s.\"/></monopd>\n", gameType.c_str());
+		m_nextGameId--;
 		return;
 	}
 
+	syslog( LOG_INFO, "new game: id=[%d], type=[%s], games=[%d]", game->id(), gameType.c_str(), m_games.size() );
+
 	game->addPlayer(player, true);
 
 	// FIXME: DEPRECATED 1.0
@@ -230,9 +240,8 @@ void MonopdServer::delGame(Game *game, bool verbose)
 			// FIXME: DEPRECATED 1.0
 			if (verbose)
 				ioWrite(std::string("<monopd><updategamelist type=\"del\"><game id=\"") + itoa(game->id()) + "\"/></updategamelist></monopd>\n");
-			printf("delGame %d/%d\n", game->id(), m_games.size());
+			syslog( LOG_INFO, "del game: id=[%d], games=[%d]", game->id(), m_games.size() - 1 );
 			m_games.erase(it);
-			printf("delGame -/%d\n", m_games.size());
 			break;
 		}
 	delete game;
@@ -268,7 +277,7 @@ Player *MonopdServer::newPlayer(Socket *socket, const std::string &name)
 	player->sendClientMsg();
 	sendGameList(player, true);
 
-	printf("new player %d/%d\n", player->id(), m_players.size());
+	syslog( LOG_INFO, "new player: id=[%d], fd=[%d], name=[%s], players=[%d]", player->id(), socket->fd(), name.c_str(), m_players.size() );
 	player = 0;
 	for(std::vector<Player *>::iterator it = m_players.begin(); it != m_players.end() && (player = *it) ; ++it)
 		printf("  player %16s %16s game %d bankrupt %d socket %d fd %d\n", player->name().c_str(), player->getStringProperty("host").c_str(), (player->game() ? player->game()->id() : -1), player->getBoolProperty("bankrupt"), player->socket(), player->socket() ? (int)player->socket()->fd() : -1);
@@ -320,17 +329,30 @@ void MonopdServer::reconnectPlayer(Player *pInput, const std::string &cookie)
 
 void MonopdServer::delPlayer(Player *player)
 {
+	// Delete timeout event, if present.
+	Game *game = player ? player->game() : 0;
+	if ( player && game )
+	{
+		Event *event = findEvent( game, dynamic_cast<GameObject *> (player) );
+		if ( event )
+		{
+			printf("cleared event for player\n");
+			event->setObject( 0 );
+		}
+		game->removePlayer( player );
+	}
+
 	ioWrite("<monopd><deleteplayer playerid=\"" + itoa(player->id()) + "\"/></monopd>\n");
 
 	for(std::vector<Player *>::iterator it = m_players.begin(); it != m_players.end() && (*it) ; ++it)
 		if (*it == player)
 		{
 			removeFromScope(player);
-			printf("del player %d/%d\n", player->id(), m_players.size());
+			syslog( LOG_INFO, "del player: id=[%d], fd=[%d], name=[%s], players=[%d]", player->id(), player->socket() ? player->socket()->fd() : 0, player->getStringProperty("name").c_str(), m_players.size() - 1 );
+			printf("delPlayer %d/%d\n", player->id(), m_players.size()-1);
 			delete player;
 			m_players.erase(it);
 			player = 0;
-			printf("del player -/%d\n", m_players.size());
 			break;
 		}
 
@@ -387,7 +409,7 @@ GameConfig *MonopdServer::newGameConfig(const std::string id, const std::string
 {
 	GameConfig *newGameConfig = new GameConfig(id, name, description);
 	m_gameConfigs.push_back(newGameConfig);
-	syslog(LOG_INFO, "loaded game config: %s", name.c_str());
+	syslog( LOG_INFO, "loaded game configuration: game=[%s]", name.c_str() );
 	return newGameConfig;
 }
 
@@ -419,6 +441,8 @@ void MonopdServer::closedSocket(Socket *socket)
 		return;
 	}
 
+	pInput->setSocket( 0 );
+	printf("%s socket 0 spec %d, bank %d, gamerun %d\n", pInput->name().c_str(), pInput->getBoolProperty("spectator"), pInput->getBoolProperty("bankrupt"), game->status() == Game::Run );
 	game->ioInfo("Connection with %s lost.", pInput->name().c_str());
 	
 	// Only remove from game when game not running, or when it's merely a spectator.
@@ -429,13 +453,12 @@ void MonopdServer::closedSocket(Socket *socket)
 			exitFromGame = true;
 		else if ( !pInput->getBoolProperty("bankrupt") )
 		{
+			printf("may reconnect\n");
 			unsigned int timeout = 180;
 			game->ioInfo("Player has %ds to reconnect until bankruptcy.", timeout);
-			pInput->setSocket(0);
-			Event *event = newEvent(Event::PlayerTimeout);
+			Event *event = newEvent( Event::PlayerTimeout, game );
 			event->setLaunchTime(time(0) + timeout);
-			GameObject *object = pInput;
-			event->setObject(object);
+			event->setObject( dynamic_cast<GameObject *> (pInput) );
 		}
 	}
 	else
@@ -443,7 +466,9 @@ void MonopdServer::closedSocket(Socket *socket)
 	
 	if (exitFromGame)
 	{
+		printf("exit from game %d: %d\n", game->id(), pInput->id());
 		exitGame(game, pInput);
+		printf("delplayer %d\n", pInput->id());
 		delPlayer(pInput);
 	}
 }
@@ -464,7 +489,15 @@ int MonopdServer::processEvents()
 			{
 			case Event::TokenMovementTimeout:
 				if (game)
+				{
 					game->tokenMovementTimeout();
+					if ( game->clientsMoving() )
+						event->setFrequency( 1 );
+					else
+						event->setFrequency( 0 );
+				}
+				else
+					event->setFrequency( 0 );
 				break;
 			case Event::SocketTimeout:
 				returnvalue = event->id();
@@ -481,6 +514,8 @@ int MonopdServer::processEvents()
 				break;
 			case Event::PlayerTimeout:
 				GameObject *object = event->object();
+				if (!object)
+					break;
 
 				Player *player;
 				player = findPlayer(object->id());
@@ -499,22 +534,31 @@ int MonopdServer::processEvents()
 					{
 						// Game might have ended, silently remove.
 						exitGame(game, player);
+						// Event might have been deleted now.
+						event = 0;
+
 						delPlayer(player);
 					}
 				}
-				event->setObject(0);
+				if ( event )
+					event->setObject(0);
 				break;
 			}
 
-			// Delete event from event list
-			int frequency = event->frequency();
-			if (frequency)
-					event->setLaunchTime(time(0) + frequency);
-			else
+			if ( event )
 			{
-				delEvent(event);
-				break; // can't use continue, damn vectors
+				// Delete event from event list
+				int frequency = event->frequency();
+				if (frequency)
+					event->setLaunchTime(time(0) + frequency);
+				else
+				{
+					delEvent(event);
+					break; // can't use continue, damn vectors
+				}
 			}
+			else
+				break;
 		} 
 	}
 	sendXMLUpdates();
@@ -550,7 +594,7 @@ void MonopdServer::loadConfig()
 	FILE *f = fopen(MONOPD_CONFIGDIR "/monopd.conf", "r");
 	if (!f)
 	{
-		syslog(LOG_ERR, "cannot open config file: %s", MONOPD_CONFIGDIR "/monopd.conf");
+		syslog( LOG_WARNING, "cannot open configuration: file=[%s]", MONOPD_CONFIGDIR "/monopd.conf" );
 		return;
 	}
 
@@ -596,7 +640,7 @@ void MonopdServer::loadGameTemplates()
 	dirp = opendir(MONOPD_DATADIR "/games/");
 	if (!dirp)
 	{
-		syslog(LOG_ERR, "cannot open config dir: %s", MONOPD_DATADIR "/games/");
+		syslog( LOG_ERR, "cannot open game directory, dir=[%s]", MONOPD_DATADIR "/games/" );
 		return;
 	}
 	while ((direntp=readdir(dirp)) != NULL)
@@ -607,7 +651,7 @@ void MonopdServer::loadGameTemplates()
 			f = fopen(filename.c_str(), "r");
 			if (!f)
 			{
-				syslog(LOG_WARNING, "cannot open config file: %s", filename.c_str());
+				syslog( LOG_WARNING, "cannot open game configuration: file=[%s/%s]", MONOPD_DATADIR "/games", filename.c_str() );
 				continue;
 			}
 
@@ -1005,7 +1049,7 @@ void MonopdServer::processCommands(Player *pInput, const std::string data2)
 					game->declareBankrupt(pInput);
 					break;
 				case 'p':
-					game->solveDebt(pInput, true);
+					game->solveDebts(pInput, true);
 					break;
 				default:
 					pInput->ioNoSuchCmd("there are debts to be settled");
